package de.intevation.flys.model;

import java.io.Serializable;
import java.util.List;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.GeneratedValue;
import javax.persistence.Column;
import javax.persistence.SequenceGenerator;
import javax.persistence.GenerationType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;

import org.hibernate.Session;
import org.hibernate.Query;

import org.apache.log4j.Logger;

import de.intevation.flys.backend.SessionHolder;


@Entity
@Table(name = "flow_velocity_model")
public class FlowVelocityModel
implements   Serializable
{
    private static Logger logger = Logger.getLogger(FlowVelocityModel.class);


    private Integer id;

    private River river;

    private DischargeZone dischargeZone;

    private List<FlowVelocityModelValue> values;

    private String description;


    public FlowVelocityModel() {
    }


    public FlowVelocityModel(River river, DischargeZone dischargeZone) {
        this(river, dischargeZone, null);
    }


    public FlowVelocityModel(
        River         river,
        DischargeZone dischargeZone,
        String        description
    ) {
        this.river         = river;
        this.dischargeZone = dischargeZone;
        this.description   = description;
    }

    @Id
    @SequenceGenerator(
        name           = "SEQUENCE_FLOW_VELOCITY_MODEL_ID_SEQ",
        sequenceName   = "FLOW_VELOCITY_MODEL_ID_SEQ",
        allocationSize = 1)
    @GeneratedValue(
        strategy  = GenerationType.SEQUENCE,
        generator = "SEQUENCE_FLOW_VELOCITY_MODEL_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return river;
    }

    public void setRiver(River river) {
        this.river = river;
    }

    @OneToOne
    @JoinColumn(name = "discharge_zone_id")
    public DischargeZone getDischargeZone() {
        return dischargeZone;
    }

    public void setDischargeZone(DischargeZone dischargeZone) {
        this.dischargeZone = dischargeZone;
    }

    @Column(name = "description")
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }


    public static List<FlowVelocityModel> getModels(
        River         river,
        DischargeZone zone
    ) {
        Session session = SessionHolder.HOLDER.get();

        Query query = session.createQuery(
            "from FlowVelocityModel where river=:river and dischargeZone=:zone");

        query.setParameter("river", river);
        query.setParameter("zone", zone);

        return query.list();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
